# pulp-2to3-migration

A [Pulp 3](https://pulpproject.org/) plugin to migrate from Pulp 2 to Pulp 3.
Supported plugins:
 - Pulp 2 ISO can be migrated into Pulp 3 File.
 - Pulp 2 Docker can be migrated into Pulp 3 Container.
 - RPM plugin migration is planned and currently in development.


For more information, please see the [documentation](https://pulp-2to3-migration.readthedocs.io/en/latest/).
